@@ -10,6 +10,7 @@ import pickle
 import time
 from typing import Self
 
+import numpy as np
 import optuna
 import pandas as pd
 import tqdm
@@ -18,9 +19,12 @@ from sklearn.metrics import (accuracy_score, brier_score_loss, log_loss,
                              precision_score, r2_score, recall_score)
 
 from .calibrator.calibrator_router import CalibratorRouter
+from .crps import crps
 from .exceptions import WavetrainException
 from .fit import Fit
-from .model.model import PREDICTION_COLUMN, PROBABILITY_COLUMN_PREFIX
+from .model.catboost.catboost_model import CatboostModel
+from .model.model import (PREDICTION_COLUMN, PROBABILITY_COLUMN_PREFIX,
+                          QUANTILE_COLUMN_PREFIX, QUANTILES)
 from .model.model_router import ModelRouter
 from .model_type import ModelType, determine_model_type
 from .reducer.combined_reducer import CombinedReducer
@@ -111,6 +115,8 @@ class Trainer(Fit):
             validation_size = 0.15
         if cutoff_dt is None:
             cutoff_dt = datetime.datetime.now()
+        if allowed_models is None:
+            allowed_models = {CatboostModel.name()}
 
         params_file = os.path.join(self._folder, _PARAMS_FILENAME)
         if walkforward_timedelta is None:
@@ -369,18 +375,37 @@ class Trainer(Fit):
                     loss = 0.0
                     pvalue = 0.0
                     log_loss_value = 0.0
-                    if determine_model_type(y_series) == ModelType.REGRESSION:
+                    model_type = determine_model_type(y_series)
+                    if model_type == ModelType.REGRESSION:
                         output = float(r2_score(y_test, y_pred[[PREDICTION_COLUMN]]))
                         print(f"R2: {output}")
+                    elif model_type == ModelType.QUANTILE_REGRESSION:
+                        y_q = y_pred[
+                            sorted(
+                                [
+                                    x
+                                    for x in y_pred.columns.values.tolist()
+                                    if QUANTILE_COLUMN_PREFIX in x
+                                ]
+                            )
+                        ]
+                        output = float(
+                            crps(y_test.to_numpy(), y_q.to_numpy(), np.array(QUANTILES))
+                        )
+                        print(f"CRPS: {output}")
                     else:
                         output = float(f1_score(y_test, y_pred[[PREDICTION_COLUMN]]))
                         print(f"F1: {output}")
                         prob_col = PROBABILITY_COLUMN_PREFIX + str(1)
                         if prob_col in y_pred.columns.values.tolist():
                             loss = float(brier_score_loss(y_test, y_pred[[prob_col]]))
-                            log_loss_value = float(
-                                log_loss(y_test.astype(float), y_pred[[prob_col]])
-                            )
+                            log_loss_value = 1.0
+                            try:
+                                log_loss_value = float(
+                                    log_loss(y_test.astype(float), y_pred[[prob_col]])
+                                )
+                            except ValueError as exc:
+                                print(str(exc))
                             pvalue = calibrator.p_value
                             print(f"Brier: {loss}")
                             print(f"Log Loss: {log_loss_value}")
@@ -389,7 +414,7 @@ class Trainer(Fit):
                             f"Accuracy: {float(accuracy_score(y_test, y_pred[[PREDICTION_COLUMN]]))}"
                         )
                         print(
-                            f"Precision: {float(precision_score(y_test, y_pred[[PREDICTION_COLUMN]]))}"
+                            f"Precision: {float(precision_score(y_test, y_pred[[PREDICTION_COLUMN]], zero_division=0.0))}"  # type: ignore
                         )
                         print(
                             f"Recall: {float(recall_score(y_test, y_pred[[PREDICTION_COLUMN]]))}"
@@ -488,6 +513,16 @@ class Trainer(Fit):
             )
 
             last_processed_dt = None
+            # If we are resuming, find the last processed datetime
+            for trial in study.trials:
+                dt_idx = datetime.datetime.fromisoformat(
+                    trial.user_attrs[_IDX_USR_ATTR_KEY]
+                )
+                if last_processed_dt is None:
+                    last_processed_dt = dt_idx
+                else:
+                    last_processed_dt = max(last_processed_dt, dt_idx)
+
             for count, test_idx in tqdm.tqdm(
                 enumerate(dt_index[dt_index >= start_test_index])
             ):
@@ -515,7 +550,7 @@ class Trainer(Fit):
                     continue
                 if (
                     last_processed_dt is not None
-                    and test_idx < last_processed_dt + self._walkforward_timedelta
+                    and test_dt < last_processed_dt + self._walkforward_timedelta
                 ):
                     continue
 
@@ -592,11 +627,16 @@ class Trainer(Fit):
             _fit_column(y)
         else:
             for col in y.columns:
-                _fit_column(y[col])
+                print(f"Training column: {col}")
+                y_train_series = y[col]
+                y_train_series.attrs = y.attrs
+                _fit_column(y_train_series)
 
         return self
 
-    def transform(self, df: pd.DataFrame, optimistic: bool = False) -> pd.DataFrame:
+    def transform(
+        self, df: pd.DataFrame, optimistic: bool = False, ignore_no_dates: bool = False
+    ) -> pd.DataFrame:
         """Predict the expected values of the data."""
         tqdm.tqdm.pandas(desc="Inferring...")
         input_df = df.copy()
@@ -621,6 +661,8 @@ class Trainer(Fit):
                     continue
                 dates.append(datetime.datetime.fromisoformat(date_str))
             if not dates:
+                if ignore_no_dates:
+                    continue
                 raise ValueError(f"no dates found for {column}.")
             dates = sorted(dates)
             bins: list[datetime.datetime] = sorted(
